//[mahjong-utils](../../index.md)/[mahjongutils.models](index.md)/[isYaochu](is-yaochu.md)

# isYaochu

[common]\
val [Tile](-tile/index.md).[isYaochu](is-yaochu.md): [Boolean](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html)

是否为幺九牌
